"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const mockPluginApi = {
    commands: {
        registerCommand: (command, callback) => {
            console.log('[Mock] Commands.registerCommand:', command);
            return {
                dispose: () => console.log('[Mock] Disposing command:', command),
            };
        },
    },
    workspace: {
        onWorkspaceLoad: (callback) => {
            console.log('[Mock] Workspace.onWorkspaceLoad registered');
            process.parentPort.on('message', async (message) => {
                if (message.data.type === 'workspaceLoaded') {
                    try {
                        await callback(message.data.payload.baseDir);
                    }
                    catch (error) {
                        console.error('Error in workspace load callback:', error);
                    }
                }
            });
            return {
                dispose: () => console.log('[Mock] Disposing workspace load handler'),
            };
        },
    },
};
const Module = require('module');
const originalLoad = Module._load;
Module._load = function (request, parent, isMain) {
    if (request === '@getvast/plugin-api') {
        console.log('[Mock] Intercepted require for @getvast/plugin-api');
        return mockPluginApi;
    }
    return originalLoad.apply(this, arguments);
};
class PluginHost {
    constructor() {
        console.debug('Plugin host initializing...');
    }
    async loadExtension(extensionPath) {
        try {
            console.log('Attempting to load extension from:', extensionPath);
            const absolutePath = path.resolve(extensionPath);
            console.log('Absolute path:', absolutePath);
            if (!fs.existsSync(absolutePath)) {
                console.error('Extension file does not exist:', absolutePath);
                console.log('Directory contents:', fs.readdirSync(path.dirname(absolutePath)));
                throw new Error(`Extension file not found: ${absolutePath}`);
            }
            let extension;
            try {
                extension = require(absolutePath);
                console.log('Extension loaded successfully. Exports:', Object.keys(extension));
            }
            catch (error) {
                console.error('Failed to require extension:', error);
                throw error;
            }
            const activate = extension.default?.activate || extension.activate;
            if (typeof activate !== 'function') {
                throw new Error('Extension must export an activate function');
            }
            const context = {
                subscriptions: [],
            };
            await activate(context);
            console.log('Extension activated successfully');
            console.log('Registered subscriptions:', context.subscriptions.length);
        }
        catch (error) {
            console.error('Failed to load extension:', error);
            throw error;
        }
    }
}
console.log('Plugin process starting...');
const host = new PluginHost();
if (process.env.PLUGIN_PATH && process.env.PLUGIN_ENTRYPOINT) {
    const extensionPath = (0, path_1.join)(process.env.PLUGIN_PATH, process.env.PLUGIN_ENTRYPOINT);
    console.log('Loading plugin from:', extensionPath);
    host.loadExtension(extensionPath).catch((error) => {
        console.error('Failed to load plugin:', error);
        process.exit(1);
    });
}
else {
    console.warn('Missing required environment variables: PLUGIN_PATH and/or PLUGIN_ENTRYPOINT');
    process.exit(1);
}
//# sourceMappingURL=plugin-process.js.map